Linux PCI subsystem development
 help / color / mirror / Atom feed
From: Damien Le Moal <dlemoal@kernel.org>
To: linux-pci@vger.kernel.org, Bjorn Helgaas <bhelgaas@google.com>
Cc: "Krzysztof Wilczyński" <kw@linux.com>,
	"Lorenzo Pieralisi" <lpieralisi@kernel.org>,
	"Kishon Vijay Abraham I" <kishon@kernel.org>,
	"Manivannan Sadhasivami" <manivannan.sadhasivam@linaro.org>,
	"Serge Semin" <fancer.lancer@gmail.com>,
	"Yoshihiro Shimoda" <yoshihiro.shimoda.uh@renesas.com>
Subject: [PATCH v4 12/16] PCI: tegra194: Use INTX instead of legacy
Date: Wed, 22 Nov 2023 15:04:02 +0900	[thread overview]
Message-ID: <20231122060406.14695-13-dlemoal@kernel.org> (raw)
In-Reply-To: <20231122060406.14695-1-dlemoal@kernel.org>

In the Designware tegra194 controller driver, change all names using
"legacy" to use "intx", to match the term used in the PCI
specifications.

Signed-off-by: Damien Le Moal <dlemoal@kernel.org>
---
 drivers/pci/controller/dwc/pcie-tegra194.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/drivers/pci/controller/dwc/pcie-tegra194.c b/drivers/pci/controller/dwc/pcie-tegra194.c
index a1f37d2d7798..e02dcbcb5970 100644
--- a/drivers/pci/controller/dwc/pcie-tegra194.c
+++ b/drivers/pci/controller/dwc/pcie-tegra194.c
@@ -773,13 +773,13 @@ static void tegra_pcie_enable_system_interrupts(struct dw_pcie_rp *pp)
 			   val_w);
 }
 
-static void tegra_pcie_enable_legacy_interrupts(struct dw_pcie_rp *pp)
+static void tegra_pcie_enable_intx_interrupts(struct dw_pcie_rp *pp)
 {
 	struct dw_pcie *pci = to_dw_pcie_from_pp(pp);
 	struct tegra_pcie_dw *pcie = to_tegra_pcie(pci);
 	u32 val;
 
 	/* Enable legacy interrupt generation */
 	val = appl_readl(pcie, APPL_INTR_EN_L0_0);
 	val |= APPL_INTR_EN_L0_0_SYS_INTR_EN;
 	val |= APPL_INTR_EN_L0_0_INT_INT_EN;
@@ -830,7 +830,7 @@ static void tegra_pcie_enable_interrupts(struct dw_pcie_rp *pp)
 	appl_writel(pcie, 0xFFFFFFFF, APPL_INTR_STATUS_L1_17);
 
 	tegra_pcie_enable_system_interrupts(pp);
-	tegra_pcie_enable_legacy_interrupts(pp);
+	tegra_pcie_enable_intx_interrupts(pp);
 	if (IS_ENABLED(CONFIG_PCI_MSI))
 		tegra_pcie_enable_msi_interrupts(pp);
 }
@@ -1947,7 +1947,7 @@ static irqreturn_t tegra_pcie_ep_pex_rst_irq(int irq, void *arg)
 	return IRQ_HANDLED;
 }
 
-static int tegra_pcie_ep_raise_legacy_irq(struct tegra_pcie_dw *pcie, u16 irq)
+static int tegra_pcie_ep_raise_intx_irq(struct tegra_pcie_dw *pcie, u16 irq)
 {
 	/* Tegra194 supports only INTA */
 	if (irq > 1)
@@ -1986,7 +1986,7 @@ static int tegra_pcie_ep_raise_irq(struct dw_pcie_ep *ep, u8 func_no,
 
 	switch (type) {
 	case PCI_IRQ_INTX:
-		return tegra_pcie_ep_raise_legacy_irq(pcie, interrupt_num);
+		return tegra_pcie_ep_raise_intx_irq(pcie, interrupt_num);
 
 	case PCI_IRQ_MSI:
 		return tegra_pcie_ep_raise_msi_irq(pcie, interrupt_num);
@@ -773,13 +773,13 @@ static void tegra_pcie_enable_system_interrupts(struct dw_pcie_rp *pp)
 	u32 val;
 
-	/* Enable legacy interrupt generation */
+	/* Enable INTX interrupt generation */
 	val = appl_readl(pcie, APPL_INTR_EN_L0_0);
 	val |= APPL_INTR_EN_L0_0_SYS_INTR_EN;
-- 
2.42.0


  parent reply	other threads:[~2023-11-22  6:04 UTC|newest]

Thread overview: 48+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-11-22  6:03 [PATCH v4 00/16] Cleanup IRQ type definitions Damien Le Moal
2023-11-22  6:03 ` [PATCH v4 01/16] PCI: Rename PCI_IRQ_LEGACY to PCI_IRQ_INTX Damien Le Moal
2023-11-22  6:15   ` Christoph Hellwig
2023-11-22  6:03 ` [PATCH v4 02/16] PCI: endpoint: Drop PCI_EPC_IRQ_XXX definitions Damien Le Moal
2023-11-22  6:15   ` Christoph Hellwig
2023-11-22  6:03 ` [PATCH v4 03/16] PCI: endpoint: Use INTX instead of legacy Damien Le Moal
2023-11-22  6:16   ` Christoph Hellwig
2023-11-22  6:03 ` [PATCH v4 04/16] PCI: endpoint: Rename LEGACY to INTX in test function driver Damien Le Moal
2023-11-22  6:16   ` Christoph Hellwig
2023-11-22  6:03 ` [PATCH v4 05/16] misc: pci_endpoint_test: Use INTX instead of LEGACY Damien Le Moal
2023-11-22  6:16   ` Christoph Hellwig
2023-11-22  6:03 ` [PATCH v4 06/16] PCI: portdrv: Use PCI_IRQ_INTX Damien Le Moal
2023-11-22  6:17   ` Christoph Hellwig
2023-11-22  6:22     ` Damien Le Moal
2023-11-22  6:23       ` Christoph Hellwig
2023-11-22  6:33         ` Damien Le Moal
2023-11-22  6:36           ` Christoph Hellwig
2023-11-22  6:49             ` Damien Le Moal
2023-11-22  6:54               ` Christoph Hellwig
2023-11-22  6:59                 ` Damien Le Moal
2023-12-19 10:07                   ` Lorenzo Pieralisi
2023-12-20  4:41                     ` Damien Le Moal
2023-11-22  6:03 ` [PATCH v4 07/16] PCI: dra7xx: Rename dra7xx_pcie_raise_legacy_irq() Damien Le Moal
2023-11-22  6:17   ` Christoph Hellwig
2023-11-22  6:03 ` [PATCH v4 08/16] PCI: cadence: Use INTX instead of legacy Damien Le Moal
2023-11-22  6:18   ` Christoph Hellwig
2023-11-22  6:03 ` [PATCH v4 09/16] PCI: dwc: Rename dw_pcie_ep_raise_legacy_irq() Damien Le Moal
2023-11-22  6:18   ` Christoph Hellwig
2023-11-22 13:38   ` Serge Semin
2023-11-22  6:04 ` [PATCH v4 10/16] PCI: keystone: Use INTX instead of legacy Damien Le Moal
2023-11-22  6:18   ` Christoph Hellwig
2023-11-22  6:04 ` [PATCH v4 11/16] PCI: dw-rockchip: Rename rockchip_pcie_legacy_int_handler() Damien Le Moal
2023-11-22  6:18   ` Christoph Hellwig
2023-11-22  6:04 ` Damien Le Moal [this message]
2023-11-22  6:18   ` [PATCH v4 12/16] PCI: tegra194: Use INTX instead of legacy Christoph Hellwig
2023-11-22  6:04 ` [PATCH v4 13/16] PCI: uniphier: " Damien Le Moal
2023-11-22  6:19   ` Christoph Hellwig
2023-11-22  6:04 ` [PATCH v4 14/16] PCI: rockchip-ep: " Damien Le Moal
2023-11-22  6:19   ` Christoph Hellwig
2023-11-22  6:04 ` [PATCH v4 15/16] PCI: rockchip-host: Rename rockchip_pcie_legacy_int_handler() Damien Le Moal
2023-11-22  6:21   ` Christoph Hellwig
2023-11-22  6:04 ` [PATCH v4 16/16] PCI: xilinx-nwl: Use INTX instead of legacy Damien Le Moal
2023-11-22  6:21   ` Christoph Hellwig
2023-11-30  8:30 ` [PATCH v4 00/16] Cleanup IRQ type definitions Damien Le Moal
2023-11-30  8:40 ` Manivannan Sadhasivami
2023-12-01  0:52 ` Bjorn Helgaas
2023-12-18 10:10   ` Damien Le Moal
2023-12-18 15:54 ` Lorenzo Pieralisi

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20231122060406.14695-13-dlemoal@kernel.org \
    --to=dlemoal@kernel.org \
    --cc=bhelgaas@google.com \
    --cc=fancer.lancer@gmail.com \
    --cc=kishon@kernel.org \
    --cc=kw@linux.com \
    --cc=linux-pci@vger.kernel.org \
    --cc=lpieralisi@kernel.org \
    --cc=manivannan.sadhasivam@linaro.org \
    --cc=yoshihiro.shimoda.uh@renesas.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox